==> atlassian-plugins-webresource-3.5.43-sources.jar: com/atlassian/plugin/webresource/CssWebResource.java <==
package com.atlassian.plugin.webresource;

import com.atlassian.plugin.webresource.impl.config.Config;
import org.apache.commons.lang.BooleanUtils;
import org.apache.commons.lang.StringEscapeUtils;
import org.apache.commons.lang.StringUtils;

import java.util.Arrays;
import java.util.List;
import java.util.Map;

public class CssWebResource extends AbstractWebResourceFormatter {
    // It should behave exactly the same with or without AMD being enabled, but, just to be sure we didn't break the
    // stuff in BTF, the new AMD behaviour will be enabled only if AMD is enabled.
    // This check should be removed in the Cloud-only version of WRM.
    private final boolean isAmdEnabled;

    /**
     * Keeping the backward compatible constructor because JIRA uses this class. It shouldn't use it, it's a private
     * implementation and not a part of the API. This constructor will be removed the next Cloud-only version of WRM.
     */
    @Deprecated
    public CssWebResource() {
        this(false);
    }

    public CssWebResource(boolean isAmdEnabled) {
        this.isAmdEnabled = isAmdEnabled;
    }

    private static final List<String> HANDLED_PARAMETERS = Arrays.asList("title", Config.MEDIA_PARAM_NAME, "charset", Config.WRM_KEY_PARAM_NAME, Config.WRM_BATCH_TYPE_PARAM_NAME);

    public boolean matches(String name) {
        return name != null && (name.endsWith(Config.CSS_EXTENSION) || (isAmdEnabled && name.endsWith(Config.LESS_EXTENSION)));
    }

    public String formatResource(String url, Map<String, String> attributes) {
        StringBuilder buffer = new StringBuilder();
        buffer.append("<link type=\"text/css\" rel=\"stylesheet\" href=\"");
        buffer.append(StringEscapeUtils.escapeHtml(url)).append("\"");
        List attributeTokens = getParametersAsAttributes(attributes);
        if (attributes != null && attributes.size() > 0) {
            buffer.append(" ").append(StringUtils.join(attributeTokens.iterator(), " "));
        }

        // default media to all
        if (!attributes.containsKey(Config.MEDIA_PARAM_NAME)) {
            buffer.append(" media=\"all\"");
        }
        buffer.append(">\n");

        // ie conditional commment
        if (attributes.containsKey(Config.CONDITIONAL_COMMENT_PARAM_NAME)) {
            String condition = attributes.get(Config.CONDITIONAL_COMMENT_PARAM_NAME);
            buffer.insert(0, "<!--[if " + condition + "]>\n");
            buffer.append("<![endif]-->\n");
        } else if (BooleanUtils.toBoolean(attributes.get(Config.IEONLY_PARAM_NAME))) {
            buffer.insert(0, "<!--[if IE]>\n");
            buffer.append("<![endif]-->\n");
        }

        return buffer.toString();
    }

    protected List<String> getAttributeParameters() {
        return HANDLED_PARAMETERS;
    }
}

==> atlassian-plugins-webresource-4.1.3-sources.jar: com/atlassian/plugin/webresource/CssWebResource.java <==
package com.atlassian.plugin.webresource;

import com.atlassian.plugin.webresource.impl.config.Config;
import org.apache.commons.lang3.BooleanUtils;
import org.apache.commons.lang3.StringEscapeUtils;
import org.apache.commons.lang3.StringUtils;

import java.util.Arrays;
import java.util.List;
import java.util.Map;

public class CssWebResource extends AbstractWebResourceFormatter {
    // It should behave exactly the same with or without AMD being enabled, but, just to be sure we didn't break the
    // stuff in BTF, the new AMD behaviour will be enabled only if AMD is enabled.
    // This check should be removed in the Cloud-only version of WRM.
    private final boolean isAmdEnabled;

    /**
     * Keeping the backward compatible constructor because JIRA uses this class. It shouldn't use it, it's a private
     * implementation and not a part of the API. This constructor will be removed the next Cloud-only version of WRM.
     */
    @Deprecated
    public CssWebResource() {
        this(false);
    }

    public CssWebResource(boolean isAmdEnabled) {
        this.isAmdEnabled = isAmdEnabled;
    }

    private static final List<String> HANDLED_PARAMETERS = Arrays.asList("title", Config.MEDIA_PARAM_NAME, "charset", Config.WRM_KEY_PARAM_NAME, Config.WRM_BATCH_TYPE_PARAM_NAME);

    public boolean matches(String name) {
        return name != null && (name.endsWith(Config.CSS_EXTENSION) || (isAmdEnabled && name.endsWith(Config.LESS_EXTENSION)));
    }

    public String formatResource(String url, Map<String, String> attributes) {
        if (!isValid(attributes)) {
            return "";
        }
        StringBuilder buffer = new StringBuilder();
        buffer.append("<link type=\"text/css\" rel=\"stylesheet\" href=\"");
        buffer.append(StringEscapeUtils.escapeHtml4(url)).append("\"");
        List attributeTokens = getParametersAsAttributes(attributes);
        if (attributes != null && attributes.size() > 0) {
            buffer.append(" ").append(StringUtils.join(attributeTokens.iterator(), " "));
        }

        // default media to all
        if (!attributes.containsKey(Config.MEDIA_PARAM_NAME)) {
            buffer.append(" media=\"all\"");
        }
        buffer.append(">\n");

        return buffer.toString();
    }

    protected List<String> getAttributeParameters() {
        return HANDLED_PARAMETERS;
    }
}
